from __future__ import annotations

from checkov.common.models.enums import CheckResult, CheckCategories
from checkov.common.util.type_forcers import force_int
from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck
from typing import Any


class DBInstanceBackupRetentionPeriod(BaseResourceCheck):
    def __init__(self) -> None:
        name = "Ensure that RDS instances has backup policy"
        id = "CKV_AWS_133"
        supported_resources = ("aws_rds_cluster", "aws_db_instance")
        categories = (CheckCategories.BACKUP_AND_RECOVERY,)
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf: dict[str, list[Any]]) -> CheckResult:
        key = "backup_retention_period"
        if key in conf.keys():
            period = conf[key][0]
            if self._is_variable_dependant(period):
                return CheckResult.UNKNOWN
            period = force_int(period)
            if period and 0 < period <= 35:
                return CheckResult.PASSED
            return CheckResult.FAILED
        # Default value is 1 which passes ^^^
        return CheckResult.PASSED

    def get_evaluated_keys(self) -> list[str]:
        return ["backup_retention_period"]


check = DBInstanceBackupRetentionPeriod()



from __future__ import annotations

from typing import TYPE_CHECKING

from checkov.common.models.enums import CheckCategories, CheckResult
from checkov.dockerfile.base_dockerfile_check import BaseDockerfileCheck

if TYPE_CHECKING:
    from dockerfile_parse.parser import _Instruction


class HealthcheckExists(BaseDockerfileCheck):
    def __init__(self) -> None:
        name = "Ensure that HEALTHCHECK instructions have been added to container images"
        id = "CKV_DOCKER_2"
        supported_instructions = ("*",)
        categories = (CheckCategories.NETWORKING,)
        super().__init__(name=name, id=id, categories=categories, supported_instructions=supported_instructions)

    def scan_resource_conf(self, conf: dict[str, list[_Instruction]]) -> tuple[CheckResult, list[_Instruction] | None]:  # type:ignore[override]  # special wildcard behaviour
        for instruction, content in conf.items():
            if instruction == "HEALTHCHECK":
                return CheckResult.PASSED, content
        return CheckResult.FAILED, None


check = HealthcheckExists()
